@@ -1,18 +1,11 @@
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE UndecidableInstances #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 {-# LANGUAGE Rank2Types #-}
-#if __GLASGOW_HASKELL__ >= 707
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE StandaloneDeriving #-}
 {-# LANGUAGE Safe #-}
-#else
--- Manual Typeable instances
-{-# LANGUAGE Trustworthy #-}
-#endif
-#include "free-common.h"
 
 -----------------------------------------------------------------------------
 -- |
@@ -56,7 +49,7 @@ import Control.Monad.State.Class
 import Control.Monad.Error.Class
 import Control.Monad.Cont.Class
 import Data.Functor.Bind
-import Data.Functor.Classes.Compat
+import Data.Functor.Classes
 import Data.Functor.WithIndex
 import Data.Foldable
 import Data.Foldable.WithIndex
@@ -66,10 +59,8 @@ import Data.Traversable.WithIndex
 import Data.Semigroup.Foldable
 import Data.Semigroup.Traversable
 import Data.Data
-import Prelude hiding (foldr)
-#if __GLASGOW_HASKELL__ >= 707
 import GHC.Generics
-#endif
+import Prelude hiding (foldr)
 
 -- $setup
 -- >>> import Control.Applicative (Const (..))
@@ -124,34 +115,20 @@ import GHC.Generics
 --
 -- * @'Free' 'Maybe'@ can be used to model a partiality monad where each layer represents running the computation for a while longer.
 data Free f a = Pure a | Free (f (Free f a))
-#if __GLASGOW_HASKELL__ >= 707
-  deriving (Typeable, Generic, Generic1)
+  deriving (Generic, Generic1)
 
 deriving instance (Typeable f, Data (f (Free f a)), Data a) => Data (Free f a)
-#endif
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance Eq1 f => Eq1 (Free f) where
   liftEq eq = go
     where
       go (Pure a)  (Pure b)  = eq a b
       go (Free fa) (Free fb) = liftEq go fa fb
       go _ _                 = False
-#else
-instance (Functor f, Eq1 f) => Eq1 (Free f) where
-  Pure a  `eq1` Pure b  = a == b
-  Free fa `eq1` Free fb = fmap Lift1 fa `eq1` fmap Lift1 fb
-  _       `eq1` _ = False
-#endif
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance (Eq1 f, Eq a) => Eq (Free f a) where
-#else
-instance (Eq1 f, Functor f, Eq a) => Eq (Free f a) where
-#endif
   (==) = eq1
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance Ord1 f => Ord1 (Free f) where
   liftCompare cmp = go
     where
@@ -159,66 +136,27 @@ instance Ord1 f => Ord1 (Free f) where
       go (Pure _)  (Free _)  = LT
       go (Free _)  (Pure _)  = GT
       go (Free fa) (Free fb) = liftCompare go fa fb
-#else
-instance (Functor f, Ord1 f) => Ord1 (Free f) where
-  Pure a `compare1` Pure b = a `compare` b
-  Pure _ `compare1` Free _ = LT
-  Free _ `compare1` Pure _ = GT
-  Free fa `compare1` Free fb = fmap Lift1 fa `compare1` fmap Lift1 fb
-#endif
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance (Ord1 f, Ord a) => Ord (Free f a) where
-#else
-instance (Ord1 f, Functor f, Ord a) => Ord (Free f a) where
-#endif
   compare = compare1
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance Show1 f => Show1 (Free f) where
   liftShowsPrec sp sl = go
     where
       go d (Pure a) = showsUnaryWith sp "Pure" d a
       go d (Free fa) = showsUnaryWith (liftShowsPrec go (liftShowList sp sl)) "Free" d fa
-#else
-instance (Functor f, Show1 f) => Show1 (Free f) where
-  showsPrec1 d (Pure a) = showParen (d > 10) $
-    showString "Pure " . showsPrec 11 a
-  showsPrec1 d (Free m) = showParen (d > 10) $
-    showString "Free " . showsPrec1 11 (fmap Lift1 m)
-#endif
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance (Show1 f, Show a) => Show (Free f a) where
-#else
-instance (Show1 f, Functor f, Show a) => Show (Free f a) where
-#endif
   showsPrec = showsPrec1
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance Read1 f => Read1 (Free f) where
   liftReadsPrec rp rl = go
     where
       go = readsData $
         readsUnaryWith rp "Pure" Pure `mappend`
         readsUnaryWith (liftReadsPrec go (liftReadList rp rl)) "Free" Free
-#else
-instance (Functor f, Read1 f) => Read1 (Free f) where
-  readsPrec1 d r = readParen (d > 10)
-      (\r' -> [ (Pure m, t)
-             | ("Pure", s) <- lex r'
-             , (m, t) <- readsPrec 11 s]) r
-    ++ readParen (d > 10)
-      (\r' -> [ (Free (fmap lower1 m), t)
-             | ("Free", s) <- lex r'
-             , (m, t) <- readsPrec1 11 s]) r
-#endif
 
-#ifdef LIFTED_FUNCTOR_CLASSES
 instance (Read1 f, Read a) => Read (Free f a) where
-#else
-instance (Read1 f, Functor f, Read a) => Read (Free f a) where
-#endif
   readsPrec = readsPrec1
 
 instance Functor f => Functor (Free f) where
@@ -260,7 +198,7 @@ instance Alternative v => Alternative (Free v) where
   {-# INLINE (<|>) #-}
 
 -- | This violates the MonadPlus laws, handle with care.
-instance (Functor v, MonadPlus v) => MonadPlus (Free v) where
+instance MonadPlus v => MonadPlus (Free v) where
   mzero = Free mzero
   {-# INLINE mzero #-}
   a `mplus` b = Free (return a `mplus` return b)
@@ -284,14 +222,12 @@ instance Foldable f => Foldable (Free f) where
         Free fa -> foldr (flip go) r fa
   {-# INLINE foldr #-}
 
-#if MIN_VERSION_base(4,6,0)
   foldl' f = go where
     go r free =
       case free of
         Pure a -> f r a
         Free fa -> foldl' go r fa
   {-# INLINE foldl' #-}
-#endif
 
 instance Foldable1 f => Foldable1 (Free f) where
   foldMap1 f = go where
@@ -326,7 +262,7 @@ instance TraversableWithIndex i f => TraversableWithIndex [i] (Free f) where
   itraverse f (Free s) = Free <$> itraverse (\i -> itraverse (f . (:) i)) s
   {-# INLINE itraverse #-}
 
-instance (Functor m, MonadWriter e m) => MonadWriter e (Free m) where
+instance MonadWriter e m => MonadWriter e (Free m) where
   tell = lift . tell
   {-# INLINE tell #-}
   listen = lift . listen . retract
@@ -334,25 +270,25 @@ instance (Functor m, MonadWriter e m) => MonadWriter e (Free m) where
   pass = lift . pass . retract
   {-# INLINE pass #-}
 
-instance (Functor m, MonadReader e m) => MonadReader e (Free m) where
+instance MonadReader e m => MonadReader e (Free m) where
   ask = lift ask
   {-# INLINE ask #-}
   local f = lift . local f . retract
   {-# INLINE local #-}
 
-instance (Functor m, MonadState s m) => MonadState s (Free m) where
+instance MonadState s m => MonadState s (Free m) where
   get = lift get
   {-# INLINE get #-}
   put s = lift (put s)
   {-# INLINE put #-}
 
-instance (Functor m, MonadError e m) => MonadError e (Free m) where
+instance MonadError e m => MonadError e (Free m) where
   throwError = lift . throwError
   {-# INLINE throwError #-}
   catchError as f = lift (catchError (retract as) (retract . f))
   {-# INLINE catchError #-}
 
-instance (Functor m, MonadCont m) => MonadCont (Free m) where
+instance MonadCont m => MonadCont (Free m) where
   callCC f = lift (callCC (retract . f . liftM lift))
   {-# INLINE callCC #-}
 
@@ -413,7 +349,7 @@ toFreeT (Free f) = FreeT.FreeT (return (FreeT.Free (fmap toFreeT f)))
 -- prop> cutoff (n+1) . lift   ==   lift . liftM Just
 -- prop> cutoff (n+1) . wrap   ==  wrap . fmap (cutoff n)
 --
--- Calling 'retract . cutoff n' is always terminating, provided each of the
+-- Calling @'retract' '.' 'cutoff' n@ is always terminating, provided each of the
 -- steps in the iteration is terminating.
 cutoff :: (Functor f) => Integer -> Free f a -> Free f (Maybe a)
 cutoff n _ | n <= 0 = return Nothing
@@ -425,7 +361,7 @@ unfold :: Functor f => (b -> Either a (f b)) -> b -> Free f a
 unfold f = f >>> either Pure (Free . fmap (unfold f))
 
 -- | Unfold a free monad from a seed, monadically.
-unfoldM :: (Traversable f, Applicative m, Monad m) => (b -> m (Either a (f b))) -> b -> m (Free f a)
+unfoldM :: (Traversable f, Monad m) => (b -> m (Either a (f b))) -> b -> m (Free f a)
 unfoldM f = f >=> either (pure . pure) (fmap Free . traverse (unfoldM f))
 
 -- | This is @Prism' (Free f a) a@ in disguise
@@ -459,45 +395,3 @@ _Free = dimap unfree (either pure (fmap Free)) . right'
   unfree (Pure x) = Left (Pure x)
   {-# INLINE unfree #-}
 {-# INLINE _Free #-}
-
-
-#if __GLASGOW_HASKELL__ < 707
-instance Typeable1 f => Typeable1 (Free f) where
-  typeOf1 t = mkTyConApp freeTyCon [typeOf1 (f t)] where
-    f :: Free f a -> f a
-    f = undefined
-
-freeTyCon :: TyCon
-#if __GLASGOW_HASKELL__ < 704
-freeTyCon = mkTyCon "Control.Monad.Free.Free"
-#else
-freeTyCon = mkTyCon3 "free" "Control.Monad.Free" "Free"
-#endif
-{-# NOINLINE freeTyCon #-}
-
-instance
-  ( Typeable1 f, Typeable a
-  , Data a, Data (f (Free f a))
-  ) => Data (Free f a) where
-    gfoldl f z (Pure a) = z Pure `f` a
-    gfoldl f z (Free as) = z Free `f` as
-    toConstr Pure{} = pureConstr
-    toConstr Free{} = freeConstr
-    gunfold k z c = case constrIndex c of
-        1 -> k (z Pure)
-        2 -> k (z Free)
-        _ -> error "gunfold"
-    dataTypeOf _ = freeDataType
-    dataCast1 f = gcast1 f
-
-pureConstr, freeConstr :: Constr
-pureConstr = mkConstr freeDataType "Pure" [] Prefix
-freeConstr = mkConstr freeDataType "Free" [] Prefix
-{-# NOINLINE pureConstr #-}
-{-# NOINLINE freeConstr #-}
-
-freeDataType :: DataType
-freeDataType = mkDataType "Control.Monad.Free.FreeF" [pureConstr, freeConstr]
-{-# NOINLINE freeDataType #-}
-
-#endif
